from distutils.core import setup
setup(
name='CQ_Nester',
version='1.0.0',
py_modules=['CQ_Nester'],
author='fumier',
author_email='fumier@163.com',
url='http://blog.csdn.net/fumier',
description='A simple printer of nested lists',
)
